@@ -1,4 +1,4 @@
-from setux.logger import info
+from setux.main.logger import info
 
 
 # pylint: disable=no-member
