@@ -1,6 +1,6 @@
 from pybrary.func import todo
 
-from setux.logger import info
+from setux.main.logger import info
 from setux.core.manage import Manager
 
 
