@@ -2,7 +2,7 @@ from time import sleep
 
 from pybrary.func import todo
 
-from setux.logger import info
+from setux.main.logger import info
 from setux.core.manage import Manager
 
 
