@@ -13,7 +13,7 @@ from .errors import (
     ModuleTypeError,
     UnsupportedDistroError,
 )
-from setux.logger import debug, info, error
+from setux.main.logger import debug, info, error
 
 from .module import Module
 from .distro import Distro
@@ -37,14 +37,14 @@ class Target:
         self.sudo = sudo
         self.chk_cnx()
         self.distros = plugins.Distros(self,
-            Distro, 'setux.lib.distros'
+            Distro, 'setux.distros'
         )
         self.managers = plugins.Managers(self,
-            Manager, 'setux.lib.managers.common'
+            Manager, 'setux.managers.common'
         )
         self.probe_distro()
         self.modules = plugins.Modules(self,
-            Module, 'setux.lib.modules'
+            Module, 'setux.modules'
         )
         self.sudo = self.distro.Login.id != 0
         self.exclude = exclude
